// @flow

import React from 'react'
import { ThemeProvider } from 'react-css-themr'
import { Element } from 'react-scroll'
import Template from 'components/Template'
import Section from 'components/Section'
import Gallery from 'components/Gallery'
import SimpleMap from 'components/SimpleMap'
import OptIn from 'components/OptIn'
import Form from 'components/Form'
import Carousel from 'components/Carousel'
import Tabs from 'components/Tabs'
import LabelValue from 'components/LabelValue'
import theme from './theme.yml'

import {
  navItems,
  languages,
  footer,
  copyright,
  summary,
  policy,
  progress,
  images,
  blocks,
  map,
  form,
} from '../../sample-data/realestate.yml'

const Home = () => (
  <ThemeProvider theme={theme}>
    <Template
      theme={theme}
      items={navItems}
      languages={languages}
      footer={{
        ...footer,
        items: navItems,
      }}
      copyright={copyright}
    >
      <div className="flex flex-wrap pt5">
        <div className="w-100 flex flex-wrap">
          <Carousel
            className="w-100 w-70-l"
            imagesToShow={1}
            items={images.items}
            renderItem={({ src }) => (
              <div className="aspect-ratio--16x9" key={src}>
                <img
                  className="absolute"
                  // className="w-100 vh-50 vh-75-l"
                  src={src}
                  alt={src}
                  onLoad={() => {
                    window.dispatchEvent(new Event('resize'))
                  }}
                />
              </div>
            )}
          />
          <div className="flex-ns items-center-ns justify-center-ns w-100 w-30-l -bg-blue pa0 pb4-m">
            <div>
              <h3 className="mb2 -bg-blue white center pa4 tc f3 fw4">Chúng tôi tư vấn miễn phí!</h3>
              <OptIn
                className=""
                requireName
                data={{
                  callToAction: 'Đặt lịch hẹn',
                }}
                theme={{
                  form: 'ph4-ns',
                  body: 'ph4 ph0-ns -bg-blue mb4 mb2-ns',
                  inputWrapper: 'bg-light-gray center ph2 pv2 ba b--light-gray mb2',
                  icon: 'mr2 black-70',
                  input: 'ph3 fw1 f6 black-70 bg-light-gray',
                  callToAction: '-bg-orange fw9 tracked pt3 w-100 ph3 pv4 pv3-ns ph2-ns br2 bn outline-0 flex-none self-stretch white f5 f6-ns',
                  errorWrapper: 'flex flex-wrap',
                  error: 'dn',
                }}
              />
            </div>
          </div>
        </div>
        <Element name={summary.id}>
          <Section
            className="w-100 bg-near-white"
            title={summary.title}
            subtitle={summary.subtitle}
            theme={{
              body: 'flex flex-wrap mt3 mt3-ns w-90-ns center',
            }}
          >
            <div className="w-100 w-50-ns pa2 ph2-ns order-1">
              {summary.items.map(({ label, value }) => (
                <LabelValue
                  key={value}
                  label={label}
                  value={value}
                />
              ))}
            </div>
            <div className="w-100 w-50-ns flex items-center ph2-ns order-0">
              <img src={images.items[0].src} alt={images.items[0].src} />
            </div>
          </Section>
        </Element>
        <Section
          className="w-100"
          title="Vị trí"
          subtitle="Gần các trung tâm thương mại lớn"
          theme={{
            body: 'flex flex-wrap',
          }}
        >
          <div className="w-100 w-50-ns">
            <img
              src="http://res.cloudinary.com/alice28/image/upload/v1495943131/vi-tri.png"
              alt="Vị trí dự án"
            />
          </div>
          <div className="w-100 w-50-ns flex items-center ph2-ns">
            <img src={images.items[0].src} alt={images.items[0].src} />
          </div>
        </Section>
        <Section
          className="w-100 -bg-pastel pb0 pb5-ns"
          title={images.title}
          subtitle={images.subtitle}
        >
          <Gallery className="w-100 flex flex-wrap" images={images.items} />
        </Section>
        <Section
          className="w-100"
          title={blocks.title}
          theme={{
            body: 'flex flex-wrap mw8 center',
          }}
        >
          <Tabs items={blocks.items} />
        </Section>
        <Section
          title={policy.title}
          className="w-100 white -bg-blue"
          theme={{
            title: 'alfa-slab-one black f2-m f1-l tc f2',
            body: 'flex flex-wrap mw8 center',
          }}
        >
          <div className="w-100 w-50-ns">
            <h3>{policy.gift.title}</h3>
            {policy.gift.items.map(({ icon, value }) => (
              <LabelValue
                key={value}
                icon={icon}
                value={value}
                theme={{
                  root: 'bn flex items-center',
                  label: 'white w2 tr flex-none',
                }}
              />
            ))}
          </div>
          <div className="w-100 w-50-ns ph2-ns">
            <h3>{policy.bankSupport.title}</h3>
            {policy.bankSupport.items.map(({ icon, label, value }) => (
              <LabelValue
                key={value}
                icon={icon}
                label={label}
                value={value}
                theme={{
                  root: 'ba b--light-gray mb1',
                  label: 'pa1 f6 fw6 white flex-none',
                  value: 'pl2',
                }}
              />
            ))}
          </div>
        </Section>
        <Section
          className="w-100 bg-near-white"
          title={progress.title}
          subtitle={progress.subtitle}
          theme={{
            body: 'flex flex-wrap mt3 mt3-ns w-90-ns center',
          }}
        >
          {progress.items.map(({ label, value }) => (
            <LabelValue
              key={value}
              label={label}
              value={value}
              theme={{
                root: 'w-100 w-50-ns flex items-center',
                label: 'w3 f6 fw6 -blue',
              }}
            />
          ))}
        </Section>
        <Section
          className="w-100 bg-near-white"
          title={map.title}
          subtitle={map.subtitle}
          theme={{
            body: 'flex flex-wrap',
          }}
        >
          <div className="w-100 w-50-ns">
            <div className="relative aspect-ratio--4x3">
              <div className="aspect-ratio--object">
                <SimpleMap
                  markers={[{
                    key: 'TCH',
                    position: map.center,
                    defaultAnimation: 2,
                  }]}
                  center={map.center}
                />
              </div>
            </div>
          </div>
          <div className="w-100 w-50-ns">
            <div className="tc">
              <h3 className="-blue f4">{form.title}</h3>
              <div className="f5">{form.subtitle}</div>
            </div>
            <Form
              fields={form.fields}
              submitText="Gọi cho tôi"
            />
          </div>
        </Section>
      </div>
    </Template>
  </ThemeProvider>
)

export default Home
