// @flow

import React from 'react'
import { themr } from 'react-css-themr'
import cn from 'classnames'
import CustomerReviewListItem from 'components/CustomerReviewListItem'

export const defaultStyles = {
  root: '',
  itemWrapper: 'w-100',
  itemRoot: 'flex-wrap ph2 pv4 ba bt-0-ns bl-0-ns br-0-ns b--light-gray br2 mv2',
  icon: 'f2 w-10-ns dn db-ns',
  meta: 'w-100 w-40-ns flex items-center',
  imageWrapper: '',
  image: 'h3 w3 pa1 br-100 ba b--light-gray',
  nameWrapper: 'pa3',
  name: 'f5 b',
  from: 'f7',
  content: 'w-100 w-50-ns',
}

const CustomerReviewList = ({
  data,
  className,
  theme,
}: {
  data: Array<TCustomerReview>,
  className?: string,
  theme: { [key: string]: string},
}) => (
  <div data-component="CustomerReviewList" className={cn(theme.root, className)}>
    {data.map(item => (
      <div key={item.name} className={theme.itemWrapper}>
        <CustomerReviewListItem
          key={item.name}
          item={item}
          theme={{
            root: theme.itemRoot,
            icon: theme.icon,
            meta: theme.meta,
            imageWrapper: theme.imageWrapper,
            image: theme.image,
            nameWrapper: theme.nameWrapper,
            name: theme.name,
            from: theme.from,
            content: theme.content,
          }}
        />
      </div>
    ))}
  </div>
)

CustomerReviewList.defaultProps = {
  className: null,
}

export default themr('CustomerReviewList', {}, { composeTheme: 'softly' })(CustomerReviewList)
