// @flow

import React from 'react'
import { storiesOf, action } from '@kadira/storybook'
import Form from './'
import {
  withLabel,
  withIconAndLabel,
  withIconAndPlaceHolder,
  misc,
} from './data.yml'

const theme = {
  root: 'ph2',
  inputWrapper: 'ph2 pv1 mb2 ba b--light-gray br2',
  icon: 'mr2',
  input: 'f5 pv2',
  label: 'f7',
  callToAction: 'w-100 pa2 bn tc black-80 br2 bg-yellow',
  error: '-red f7 w-100 w-third-ns',
}

const validate = ({ email, phone }) => {
  const errors = {
    email: !email ? 'Email is required' : undefined,
    phone: !phone ? 'Phone is required' : undefined,
  }
  return errors
}

storiesOf('Form', module)
  .add('With Label', () => (
    <Form
      fields={withLabel}
      submitText="Subscribe Now"
      validate={validate}
      onSubmit={action('submit')}
      onValidationFail={action('validate fail')}
      showErrors={false}
      theme={theme}
    />
  ))
  .add('With Icon And Label', () => (
    <Form
      fields={withIconAndLabel}
      submitText="Subscribe Now"
      validate={validate}
      onSubmit={action('submit')}
      onValidationFail={action('validate fail')}
      showErrors={false}
      theme={theme}
    />
  ))
  .add('With Icon And Placeholder', () => (
    <Form
      fields={withIconAndPlaceHolder}
      submitText="Subscribe Now"
      validate={validate}
      onSubmit={action('submit')}
      onValidationFail={action('validate fail')}
      showErrors={false}
      theme={theme}
    />
  ))
  .add('Misc', () => (
    <Form
      fields={misc}
      submitText="Subscribe Now"
      validate={validate}
      onSubmit={action('submit')}
      onValidationFail={action('validate fail')}
      showErrors={false}
      theme={theme}
    />
  ))
