// @flow

import React from 'react'
import { compose, withState } from 'recompose'
import { themr } from 'react-css-themr'
import cn from 'classnames'

const Tabs = ({
  items,
  selected,
  select,
  className,
  theme,
}: {
  items: Array<{ title: string, image: string }>,
  selected: number,
  select: (selected: number) => void,
  className?: string,
  theme: {[ key: string]: string },
}) => (
  <div
    data-component="Tabs"
    className={cn(theme.root, className)}
  >
    <div className={theme.tabWrapper}>
      {items.map(({ title }, idx) => (
        <div
          key={title}
          className={cn(theme.item, { [theme.selected]: selected === idx })}
          onClick={() => select(idx)}
        >
          {title}
        </div>
      ))}
    </div>
    <div className={theme.body}>
      <img src={items[selected].image} alt={items[selected].title} />
    </div>
  </div>
)

Tabs.defaultProps = {
  className: null,
}

export default compose(
  themr('Tabs', {}, { composeTheme: 'softly' }),
  withState('selected', 'select', 0),
)(Tabs)
