// @flow

import React from 'react'
import { themr } from 'react-css-themr'
import cn from 'classnames'
import { FormInput } from 'react-form'
import Icon from 'components/Icon'

const TextInput = ({
  field,
  type = 'text',
  multiline = false,
  icon,
  label,
  className,
  theme,
  ...rest
}: {
  field: string,
  type: string,
  multiline: boolean,
  icon: string,
  label?: string,
  className?: string,
  theme: { [key: string]: string},
}) => {
  const Input = multiline ? 'textarea' : 'input'
  return (
    <FormInput
      className={cn(theme.root, className)}
      field={field}
      showErrors={false}
    >
      {({ setValue, getValue, setTouched }) => (
        <div>
          {!!label && (
            <label className={theme.label} htmlFor={field}>{label}</label>
          )}
          <div className="flex items-center">
            {!!icon && (
              <Icon key="icon" className={theme.icon} name={icon} />
            )}
            <Input
              key="input"
              name={field}
              className={cn('flex-auto input-reset outline-0 bn', theme.input)}
              type={type}
              {...rest} // Send the rest of your props to React-Select
              value={getValue() || ''} // Set the value to the forms value
              onChange={(e) => {
                setValue(e.target.value)
              }} // On Change, update the form value
              onBlur={() => setTouched()}
            />
          </div>
        </div>
      )}
    </FormInput>
  )
}

TextInput.defaultProps = {
  className: undefined,
  label: undefined,
}

export default themr('TextInput', {}, { composeTheme: 'softly' })(TextInput)
